make_output will make a clean csv presenting the results from your run
of classify. If you are planning to avoid typing absolute paths, you need to first
set your working directory to the location where you stored your images folder and data_info csv.
If you set this function to run and assign it to a variable, you can specify return_df=TRUE
and produce a variable in your R session that is the model output.
1 2 3 4 5 6 7 8 9 | make_output(
output_location,
model_dir,
output_name = "MLWIC2_output.csv",
saved_predictions = "model_predictions.txt",
return_df = FALSE,
top_n = "5",
shiny = FALSE
)
|
output_location |
Absolute path where you want the output csv stored. This path must exist on your computer. |
model_dir |
Absolute path to the 'MLWIC2_helper_files' folder |
output_name |
Desired name of the output file. It must end in '.csv' |
saved_predictions |
This is the file name where you stored predictions when you ran
|
return_df |
If TRUE, this will return the model output. This allows you to create a variable that is the model output. |
top_n |
The number of guesses that you wanted classify to save. This needs to mach what you specified
for top_n in |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.