setup installs necessary Python packages on your computer. You will
need to run this before running classify and train. If this is your first time using
this function, you should see additional documentation at https://github.com/mikeyEcology/MLWIC2.
If you follow the link to install Anacoda and you are using a Mac, python should be in the default location.
1 2 3 4 5 6 7 8 |
python_loc |
The location of python on your machine. If you are using a Macintosh, the default is the likely location. |
gpu |
Logical. Do you want to use a GPU for classifying and training. (You must have a GPU on your machine for this to work). |
conda_loc |
The location of conda. It is usually in the same folder as python |
r_reticulate |
Logical. Do you have an environment called "r-reticulate" for which you have installed Python packages previously and want to retain these packages. Default is FALSE. |
python_version |
set to the version of python you want to use. Use <= 3.7 |
envname |
The name of the conda environment you'd like to set up. If you don't manage multiple environments, leave this as default |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.